package rope

  1. Overview
  2. Docs

Module Rope.Rope_toploopSource

Toploop printer and its configuration.

Sourceval printer : Format.formatter -> rope -> unit

Toploop printer for rope values. The value will be printed alike a standard string except that one will display at most !max_display_length characters from the rope in order to allow convenient interactive manipulations of long ropes. In case the rope display is truncated, !ellipsis is appended after the closing quote.

Sourceval max_display_length : int ref

Maximum number of characters displayed. Default: 400.

Sourceval ellipsis : string ref

String used a ellipsis for truncated ropes. Default: "...".